Index: BUGS
===================================================================
--- BUGS	(revision 53996)
+++ BUGS	(working copy)
@@ -208,7 +208,7 @@
 * vdeck truncates the region names in the 'regions' file, probably
   wrong bu_strlcpy() length.
 
-* hyp tesselation routine creates bot that does not raytrace
+* hyp tessellation routine creates bot that does not raytrace
 
 * if you attach a display manager in tk-mged, kill the window, then
   quit, mged crashes on exit.
Index: ChangeLog
===================================================================
--- ChangeLog	(revision 53996)
+++ ChangeLog	(working copy)
@@ -2695,7 +2695,7 @@
 
 	* [r50930] NEWS:
 	  richard changed some tolerances that were preventing some pipe
-	  bends from tesselating. he changed some compares from 0.0 to
+	  bends from tessellating. he changed some compares from 0.0 to
 	  SMALL_FASTF affecting 90 degree bends (untested) and pipes with
 	  inner/outer diameters. he also relaxed near-zero comparison of
 	  the normal (which affects linear segments).
@@ -26868,7 +26868,7 @@
 2011-12-01 15:01  brlcad
 
 	* [r47723] src/librt/primitives/pipe/pipe.c:
-	  prevent a pipe tesselation double-free, detected by the
+	  prevent a pipe tessellation double-free, detected by the
 	  conversion script and verbose blather on linux
 
 2011-12-01 14:43  brlcad
Index: doc/cvs.txt
===================================================================
--- doc/cvs.txt	(revision 53996)
+++ doc/cvs.txt	(working copy)
@@ -530,7 +530,7 @@
     chunks.  See the patch manual documentation for more details.
 
     Failing any of the above, patches may also be applied manually.
-    This is often even desireable to become more familiar with the
+    This is often even desirable to become more familiar with the
     changes being made providing an opportunity for a healthy peer
     review.
 
Index: doc/docbook/system/man1/en/g-acad.xml
===================================================================
--- doc/docbook/system/man1/en/g-acad.xml	(revision 53996)
+++ doc/docbook/system/man1/en/g-acad.xml	(working copy)
@@ -54,7 +54,7 @@
 <option>-r</option>
 , and
 <option>-n</option>
-options specify tesselation tolerances.
+options specify tessellation tolerances.
 The
 <option>-D</option>
 option specifies a calculational distance tolerance (mm). Any two vertices
Index: doc/docbook/system/man1/en/g-egg.xml
===================================================================
--- doc/docbook/system/man1/en/g-egg.xml	(revision 53996)
+++ doc/docbook/system/man1/en/g-egg.xml	(working copy)
@@ -53,7 +53,7 @@
 <option>-r</option>
 , and
 <option>-n</option>
-options specify tesselation tolerances.
+options specify tessellation tolerances.
 The
 <option>-D</option>
 option specifies a calculational distance tolerance (mm). Any two vertices
Index: doc/docbook/system/man1/en/g-euclid.xml
===================================================================
--- doc/docbook/system/man1/en/g-euclid.xml	(revision 53996)
+++ doc/docbook/system/man1/en/g-euclid.xml	(working copy)
@@ -56,7 +56,7 @@
 <option>-r</option>
 , and
 <option>-n</option>
-options specify tesselation tolerances. The
+options specify tessellation tolerances. The
 <option>-o</option>
 option specifies the name of the file to receive the output
 (stdout is the default).</para>
Index: doc/docbook/system/man1/en/g-iges.xml
===================================================================
--- doc/docbook/system/man1/en/g-iges.xml	(revision 53996)
+++ doc/docbook/system/man1/en/g-iges.xml	(working copy)
@@ -66,19 +66,19 @@
   <varlistentry>
   <term><option>-a </option><emphasis remap='I'>abs_tol</emphasis></term>
   <listitem>
-<para>Sets the absolute tolerance (floating point value) for tesselation.</para>
+<para>Sets the absolute tolerance (floating point value) for tessellation.</para>
   </listitem>
   </varlistentry>
   <varlistentry>
   <term><option>-r </option><emphasis remap='I'>rel_tol</emphasis></term>
   <listitem>
-<para>Sets the relative (to the size of the object) tolerance (floating point value) for tesselation.</para>
+<para>Sets the relative (to the size of the object) tolerance (floating point value) for tessellation.</para>
   </listitem>
   </varlistentry>
   <varlistentry>
   <term><option>-n </option><emphasis remap='I'>norm_tol</emphasis></term>
   <listitem>
-<para>Sets the normal tolerance (floating point value 0..1) for tesselation.
+<para>Sets the normal tolerance (floating point value 0..1) for tessellation.
 This value is compared to the dot product of the normals to determine if the surfaces are within tolerance</para>
 
   </listitem>
Index: doc/docbook/system/man1/en/g-nff.xml
===================================================================
--- doc/docbook/system/man1/en/g-nff.xml	(revision 53996)
+++ doc/docbook/system/man1/en/g-nff.xml	(working copy)
@@ -55,7 +55,7 @@
 <option>-r</option>
 , and
 <option>-n</option>
-options specify tesselation tolerances.
+options specify tessellation tolerances.
 The
 <option>-D</option>
 option specifies a calculational distance tolerance (mm). Any two vertices
Index: doc/docbook/system/man1/en/g-nmg.xml
===================================================================
--- doc/docbook/system/man1/en/g-nmg.xml	(revision 53996)
+++ doc/docbook/system/man1/en/g-nmg.xml	(working copy)
@@ -88,8 +88,8 @@
 This allows small objects to be tessellated with small tolerances, while large objects are tessellated with large tolerances.
 For example, specifying
 <option>-r 0.1</option>
-when tesselating an object 2m in size, will result in a tolerance of .2m (2.0 * 0.1).
-The same option will cause a 5cm object to be tesselated with a tolerance of 0.5cm.</para>
+when tessellating an object 2m in size, will result in a tolerance of .2m (2.0 * 0.1).
+The same option will cause a 5cm object to be tessellated with a tolerance of 0.5cm.</para>
   </listitem>
   </varlistentry>
   <varlistentry>
@@ -140,7 +140,7 @@
 </refsect1>
 
 <refsect1 xml:id='bugs'><title>BUGS</title>
-<para>Boolean operations under finite precision arithmetic are not guaranteed to be solvable.  As a result this command can fail.  Scaling geometry adjusting tolerance values, and restructuring the boolean tree will often result in a successful tesselation.</para>
+<para>Boolean operations under finite precision arithmetic are not guaranteed to be solvable.  As a result this command can fail.  Scaling geometry adjusting tolerance values, and restructuring the boolean tree will often result in a successful tessellation.</para>
 
 </refsect1>
 
Index: doc/docbook/system/man1/en/g-obj.xml
===================================================================
--- doc/docbook/system/man1/en/g-obj.xml	(revision 53996)
+++ doc/docbook/system/man1/en/g-obj.xml	(working copy)
@@ -56,7 +56,7 @@
 <option>-r</option>
 , and
 <option>-n</option>
-options specify tesselation tolerances.
+options specify tessellation tolerances.
 The
 <option>-D</option>
 option specifies a calculational distance tolerance (mm). Any two vertices
Index: doc/docbook/system/man1/en/g-stl.xml
===================================================================
--- doc/docbook/system/man1/en/g-stl.xml	(revision 53996)
+++ doc/docbook/system/man1/en/g-stl.xml	(working copy)
@@ -54,7 +54,7 @@
 <option>-r</option>
 , and
 <option>-n</option>
-options specify tesselation tolerances.
+options specify tessellation tolerances.
 The
 <option>-D</option>
 option specifies a calculational distance tolerance (mm). Any two vertices
Index: doc/docbook/system/man1/en/g-tankill.xml
===================================================================
--- doc/docbook/system/man1/en/g-tankill.xml	(revision 53996)
+++ doc/docbook/system/man1/en/g-tankill.xml	(working copy)
@@ -61,7 +61,7 @@
 <option>-r</option>
 , and
 <option>-n</option>
-options specify tesselation tolerances. The
+options specify tessellation tolerances. The
 <option>-o</option>
 option specifies the name of the file to receive the output
 (stdout is the default). The
Index: doc/html/ReleaseNotes/email4.0.html
===================================================================
--- doc/html/ReleaseNotes/email4.0.html	(revision 53996)
+++ doc/html/ReleaseNotes/email4.0.html	(working copy)
@@ -1073,7 +1073,7 @@
 
 <p>
 I have a very preliminary version of lighting model support in MGED,
-to help debug the NMG tesselation routines.  It uses 4 infinite lights
+to help debug the NMG tessellation routines.  It uses 4 infinite lights
 of dubious color and location, but it helps see the facets (eg, on the TGC)
 very clearly.  As usual, getting the SGI to do anything useful has turned
 out to be a much bigger fight than I had expected.
Index: doc/html/ReleaseNotes/email4.4.html
===================================================================
--- doc/html/ReleaseNotes/email4.4.html	(revision 53996)
+++ doc/html/ReleaseNotes/email4.4.html	(working copy)
@@ -4883,7 +4883,7 @@
 
 <p>
 	1. What to do with solids that are not in IGES and are not
-	   tesselated (like the half-space solid).
+	   tessellated (like the half-space solid).
 
 <p>
 	2. IGES cannot handle an object that is scaled. If a scaled object
Index: doc/html/ReleaseNotes/email5.0.html
===================================================================
--- doc/html/ReleaseNotes/email5.0.html	(revision 53996)
+++ doc/html/ReleaseNotes/email5.0.html	(working copy)
@@ -3378,7 +3378,7 @@
 &gt; same hardware) when its file sizes get to be large (&gt;15 Mb).
 
 <p>
-	Both the NMG and the polysolid are very sensitive to tesselation
+	Both the NMG and the polysolid are very sensitive to tessellation
 tolerances. It is very easy to create an outrageously large NMG or
 polysolid file from a simple curved surface primitive, just by selecting
 a very small tolerance. The polysolid is more compact than the NMG
Index: doc/html/manuals/librt/dg_obj.html
===================================================================
--- doc/html/manuals/librt/dg_obj.html	(revision 53996)
+++ doc/html/manuals/librt/dg_obj.html	(working copy)
@@ -96,7 +96,7 @@
 </DD>
 <P>
 <DT><I>dgName</I> <A NAME="ev"><B>ev</B></A> [<I>-dnqstuvwT</I>] [<I>-P #</I>] &lt;<I>objects</I>&gt</DT>
-<DD>Evaluate the <I>objects</I> specified by tesselating
+<DD>Evaluate the <I>objects</I> specified by tessellating
 all <a href="../mged/brlcad_glossary.html#SOLID">primitive solids</a> in the objects
 and then performing any <a href="../mged/brlcad_glossary.html#BOOLEAN">Boolean operations</a>
 specified in the <I>objects</I>. The result is then added to the display list
Index: doc/html/manuals/librt/wdb_obj.html
===================================================================
--- doc/html/manuals/librt/wdb_obj.html	(revision 53996)
+++ doc/html/manuals/librt/wdb_obj.html	(working copy)
@@ -434,23 +434,23 @@
 then that tolerance setting will be modified. The keywords are:
 
 <ul>
-<li>Tesselation tolerances:<br>
-	The tesselation tolerances are used to control the facetization of
+<li>Tessellation tolerances:<br>
+	The tessellation tolerances are used to control the facetization of
 	<a href="../mged/brlcad_glossary.html#SOLID">primitive solids</a>. If more than one
-	tolerance value is specified, the tesselation is performed to meet the most stringent.</li>
+	tolerance value is specified, the tessellation is performed to meet the most stringent.</li>
 	<ul>
 	<li>abs -- This <I>absolute</I> tolerance is specified in model units and represents the maximum
 		allowable error in the distance from the actual solid surface to the
-		tesselated surface. An <I>absolute</I> tolerance of 0 means that the
+		tessellated surface. An <I>absolute</I> tolerance of 0 means that the
 		<I>absolute</I> tolerance should be ignored.</li>
 	<li>rel -- This <I>relative</I> tolerance is specified in terms of a fraction
 		of the solid size. The value is multiplied by the size of the solid to
 		determine another bound on the maximum
                 allowable error in the distance from the actual solid surface to the
-                tesselated surface. An <I>relative</I> tolerance of 0 means that the
+                tessellated surface. An <I>relative</I> tolerance of 0 means that the
                 <I>relative</I> tolerance should be ignored.
 	<li>norm -- This <I>normal</I> tolerance is specified in degrees and represents the maximum angle
-		between the actual solid surface normal and the tesselated surface normal.
+		between the actual solid surface normal and the tessellated surface normal.
 		A <I>normal</I> tolerance of 0 means that the <I>normal</I> tolerance
 		should be ignored.</li>
 	</ul>
Index: doc/html/manuals/mged/mged.html
===================================================================
--- doc/html/manuals/mged/mged.html	(revision 53996)
+++ doc/html/manuals/mged/mged.html	(working copy)
@@ -209,7 +209,7 @@
 </pre>
 <A name="#foobar">At</a> this point, mged is asking what type of geometry display window you
 would like.&nbsp; The default is always ``nu'' for Null or ``no geometry display''.&nbsp;
-If you are creating geometry, it is desireable to be able to see it.&nbsp;
+If you are creating geometry, it is desirable to be able to see it.&nbsp;
 The common choices are:
 <center>
 <table border>
Index: doc/html/manuals/mged/mged1.html
===================================================================
--- doc/html/manuals/mged/mged1.html	(revision 53996)
+++ doc/html/manuals/mged/mged1.html	(working copy)
@@ -207,7 +207,7 @@
 </pre>
 <A name="#foobar">At</a> this point, mged is asking what type of geometry display window you
 would like.&nbsp; The default is always ``nu'' for Null or ``no geometry display''.&nbsp;
-If you are creating geometry, it is desireable to be able to see it.&nbsp;
+If you are creating geometry, it is desirable to be able to see it.&nbsp;
 The common choices are:
 <center>
 <table border>
Index: doc/html/manuals/mged/shaders.html
===================================================================
--- doc/html/manuals/mged/shaders.html	(revision 53996)
+++ doc/html/manuals/mged/shaders.html	(working copy)
@@ -130,7 +130,7 @@
 Vscale can specify the grid size in X, Y and Z.
 <dt><b>Delta</b>
 <dd>This specifies a translation in noise space for the origin of region space.
-Since the origin of noise space is reflected 8 ways, it is undesireable to have
+Since the origin of noise space is reflected 8 ways, it is undesirable to have
 that portion of noise space overlap with region space.
 </dl>
 <H3>Examples</h3>
@@ -199,7 +199,7 @@
 Vscale can specify the grid size in X, Y and Z.
 <dt><b>Delta</b>
 <dd>This specifies a translation in noise space for the origin of region space.
-Since the origin of noise space is reflected 8 ways, it is undesireable to have
+Since the origin of noise space is reflected 8 ways, it is undesirable to have
 that portion of noise space overlap with region space.
 </dl>
 
@@ -648,7 +648,7 @@
 
 <DT><a NAME="texture"><B>texture</B></DT>
 <DD>maps a .pix file onto an object using u,v coordinates.
-This is usually undesireable for objects made up of more than one primitive solid.
+This is usually undesirable for objects made up of more than one primitive solid.
 </DD>
 
 <H3>Parameters</h3>
Index: doc/html/manuals/shaders/camo.html
===================================================================
--- doc/html/manuals/shaders/camo.html	(revision 53996)
+++ doc/html/manuals/shaders/camo.html	(working copy)
@@ -55,7 +55,7 @@
 Vscale can specify the grid size in X, Y and Z.
 <dt><b>Delta</b>
 <dd>This specifies a translation in noise space for the origin of region space.
-Since the origin of noise space is reflected 8 ways, it is undesireable to have
+Since the origin of noise space is reflected 8 ways, it is undesirable to have
 that portion of noise space overlap with region space.
 </dl>
 
Index: src/adrt/load_g.c
===================================================================
--- src/adrt/load_g.c	(revision 53996)
+++ src/adrt/load_g.c	(working copy)
@@ -244,7 +244,7 @@
 load_g (struct tie_s *tie, const char *db, int argc, const char **argv, struct adrt_mesh_s **meshes)
 {
     struct model *the_model;
-    struct rt_tess_tol ttol;		/* tesselation tolerance in mm */
+    struct rt_tess_tol ttol;		/* tessellation tolerance in mm */
     struct db_tree_state tree_state;	/* includes tol & model */
 
     cur_tie = tie;	/* blehhh, global... need locking. */
@@ -254,7 +254,7 @@
     tree_state.ts_ttol = &ttol;
     tree_state.ts_m = &the_model;
 
-    /* Set up tesselation tolerance defaults */
+    /* Set up tessellation tolerance defaults */
     ttol.magic = RT_TESS_TOL_MAGIC;
     /* Defaults, updated by command line options. */
     ttol.abs = 0.0;
Index: src/conv/g-acad.c
===================================================================
--- src/conv/g-acad.c	(revision 53996)
+++ src/conv/g-acad.c	(working copy)
@@ -605,7 +605,7 @@
     fprintf(fpe, "Objects:");
     for (i=1; i<argc; i++)
 	fprintf(fpe, " %s", argv[i]);
-    fprintf(fpe, "\nTesselation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
+    fprintf(fpe, "\nTessellation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
 	    tree_state.ts_ttol->abs, tree_state.ts_ttol->rel, tree_state.ts_ttol->norm);
     fprintf(fpe, "Calculational tolerances:\n\tdist = %g mm perp = %g\n",
 	    tree_state.ts_tol->dist, tree_state.ts_tol->perp);
@@ -614,7 +614,7 @@
     bu_log("Objects:");
     for (i=1; i<argc; i++)
 	bu_log(" %s", argv[i]);
-    bu_log("\nTesselation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
+    bu_log("\nTessellation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
 	   tree_state.ts_ttol->abs, tree_state.ts_ttol->rel, tree_state.ts_ttol->norm);
     bu_log("Calculational tolerances:\n\tdist = %g mm perp = %g\n",
 	   tree_state.ts_tol->dist, tree_state.ts_tol->perp);
Index: src/conv/g-nff.c
===================================================================
--- src/conv/g-nff.c	(revision 53996)
+++ src/conv/g-nff.c	(working copy)
@@ -479,7 +479,7 @@
     fprintf(fpe, "Objects:");
     for (i = 1; i < argc; i++)
 	fprintf(fpe, " %s", argv[i]);
-    fprintf(fpe, "\nTesselation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
+    fprintf(fpe, "\nTessellation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
 	    tree_state.ts_ttol->abs, tree_state.ts_ttol->rel, tree_state.ts_ttol->norm);
     fprintf(fpe, "Calculational tolerances:\n\tdist = %g mm perp = %g\n",
 	    tree_state.ts_tol->dist, tree_state.ts_tol->perp);
@@ -488,7 +488,7 @@
     bu_log("Objects:");
     for (i = 1; i < argc; i++)
 	bu_log(" %s", argv[i]);
-    bu_log("\nTesselation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
+    bu_log("\nTessellation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
 	   tree_state.ts_ttol->abs, tree_state.ts_ttol->rel, tree_state.ts_ttol->norm);
     bu_log("Calculational tolerances:\n\tdist = %g mm perp = %g\n",
 	   tree_state.ts_tol->dist, tree_state.ts_tol->perp);
Index: src/conv/g-vrml.c
===================================================================
--- src/conv/g-vrml.c	(revision 53996)
+++ src/conv/g-vrml.c	(working copy)
@@ -278,9 +278,9 @@
 }
 
 
-/* CSG objects are tesselated and stored in the tree. BOTs are
+/* CSG objects are tessellated and stored in the tree. BOTs are
  * processed but stored outside tree. This leaf-tess function is
- * used when we want CSG objects tesselated and evaluated but we
+ * used when we want CSG objects tessellated and evaluated but we
  * want to output BOTs without boolean evaluation.
  */
 union tree *
Index: src/conv/tankill/g-tankill.c
===================================================================
--- src/conv/tankill/g-tankill.c	(revision 53996)
+++ src/conv/tankill/g-tankill.c	(working copy)
@@ -48,9 +48,9 @@
 		v - verbose\n\
 		x - librt debug level\n\
 		X - NMG debug level\n\
-		a - absolute tolerance for tesselation\n\
-		r - relative tolerance for tesselation\n\
-		n - surface normal tolerance for tesselation\n\
+		a - absolute tolerance for tessellation\n\
+		r - relative tolerance for tessellation\n\
+		n - surface normal tolerance for tessellation\n\
 		s - surroundings code to use in tankill file\n\
 		i - assign new idents sequentially and output ident list\n\
 		o - TANKILL output file\n";
Index: src/external/Cubit/g-sat.cpp
===================================================================
--- src/external/Cubit/g-sat.cpp	(revision 53996)
+++ src/external/Cubit/g-sat.cpp	(working copy)
@@ -77,7 +77,7 @@
 
 static  db_i		*dbip;
 
-static  rt_tess_tol     ttol;   /* tesselation tolerance in mm */
+static  rt_tess_tol     ttol;   /* tessellation tolerance in mm */
 static  bn_tol          tol;    /* calculation tolerance */
 
 // Global map for bodies names in the CGM global list
Index: src/external/ProEngineer/proe_brl.res
===================================================================
--- src/external/ProEngineer/proe_brl.res	(revision 53996)
+++ src/external/ProEngineer/proe_brl.res	(working copy)
@@ -102,12 +102,12 @@
 		(max_angle_ctrl_l.AttachRight	True)
 		(max_angle_ctrl.InputType	3)
 		(max_angle_ctrl.Value		"0.5")
-		(max_angle_ctrl.HelpText	"(0.0 - 1.0) larger values here produce finer tesselations")
+		(max_angle_ctrl.HelpText	"(0.0 - 1.0) larger values here produce finer tessellations")
 		(min_angle_ctrl_l.Label		"Min Angle Control Value: ")
 		(min_angle_ctrl_l.AttachRight	True)
 		(min_angle_ctrl.InputType	3)
 		(min_angle_ctrl.Value		"0.5")
-		(min_angle_ctrl.HelpText	"(0.0 - 1.0) larger values here produce finer tesselations")
+		(min_angle_ctrl.HelpText	"(0.0 - 1.0) larger values here produce finer tessellations")
 		(isteps_l.Label			"Max to Min Control Steps: ")
 		(isteps_l.AttachRight		True)
 		(isteps.InputType		2)
Index: src/external/Unigraphics/ug-g.c
===================================================================
--- src/external/Unigraphics/ug-g.c	(revision 53996)
+++ src/external/Unigraphics/ug-g.c	(working copy)
@@ -114,7 +114,7 @@
 
 static double tol_dist=0.0005;	/* (mm) minimum distance between two distinct vertices */
 static double tol_dist_sq;
-static double surf_tol=3.175;	/* (mm) allowable surface tesselation tolerance (default is 1/8 inch) */
+static double surf_tol=3.175;	/* (mm) allowable surface tessellation tolerance (default is 1/8 inch) */
 static double ang_tol=0.0;
 static double min_chamfer=0.0;	/* (mm) chamfers smaller than this are ignored */
 static double min_round=0.0;	/* (mm) rounds smaller than this are ignored */
Index: src/libged/tol.c
===================================================================
--- src/libged/tol.c	(revision 53996)
+++ src/libged/tol.c	(working copy)
@@ -48,7 +48,7 @@
     /* print all tolerance settings */
     if (argc == 1) {
 	bu_vls_printf(gedp->ged_result_str, "Current tolerance settings are:\n");
-	bu_vls_printf(gedp->ged_result_str, "Tesselation tolerances:\n");
+	bu_vls_printf(gedp->ged_result_str, "Tessellation tolerances:\n");
 
 	if (gedp->ged_wdbp->wdb_ttol.abs > 0.0) {
 	    bu_vls_printf(gedp->ged_result_str, "\tabs %g mm\n", gedp->ged_wdbp->wdb_ttol.abs);
Index: src/libged/wdb_obj.c
===================================================================
--- src/libged/wdb_obj.c	(revision 53996)
+++ src/libged/wdb_obj.c	(working copy)
@@ -6347,7 +6347,7 @@
     /* print all tolerance settings */
     if (argc == 1) {
 	Tcl_AppendResult(wdbp->wdb_interp, "Current tolerance settings are:\n", (char *)NULL);
-	Tcl_AppendResult(wdbp->wdb_interp, "Tesselation tolerances:\n", (char *)NULL);
+	Tcl_AppendResult(wdbp->wdb_interp, "Tessellation tolerances:\n", (char *)NULL);
 
 	if (wdbp->wdb_ttol.abs > 0.0) {
 	    bu_vls_init(&vls);
Index: src/librt/primitives/ars/ars.c
===================================================================
--- src/librt/primitives/ars/ars.c	(revision 53996)
+++ src/librt/primitives/ars/ars.c	(working copy)
@@ -534,7 +534,7 @@
     }
 
     if (bad_ars) {
-	bu_log("TESSELATION FAILURE: This ARS solid has not been tesselated.\n\tAny result you may obtain is incorrect.\n");
+	bu_log("TESSELATION FAILURE: This ARS solid has not been tessellated.\n\tAny result you may obtain is incorrect.\n");
 	return -1;
     }
 
Index: src/librt/primitives/brep/brep.cpp
===================================================================
--- src/librt/primitives/brep/brep.cpp	(revision 53996)
+++ src/librt/primitives/brep/brep.cpp	(working copy)
@@ -2603,7 +2603,7 @@
  *
  * There are several ways to visualize NURBS surfaces, depending on
  * the purpose.  For "normal" wireframe viewing, the ideal approach is
- * to do a tesselation of the NURBS surface and show that wireframe.
+ * to do a tessellation of the NURBS surface and show that wireframe.
  * The quicker and simpler approach is to visualize the edges,
  * although that can sometimes generate less than ideal/useful results
  * (for example, a revolved edge that forms a sphere will have a
Index: src/librt/primitives/metaball/metaball_tri.c
===================================================================
--- src/librt/primitives/metaball/metaball_tri.c	(revision 53996)
+++ src/librt/primitives/metaball/metaball_tri.c	(working copy)
@@ -21,7 +21,7 @@
 /** @{ */
 /** @file primitives/metaball/metaball_tri.c
  *
- * Tesselation/facetization routines for the metaball primitive.
+ * Tessellation/facetization routines for the metaball primitive.
  *
  * Here be magic.
  *
Index: src/librt/primitives/nmg/nmg_bool.c
===================================================================
--- src/librt/primitives/nmg/nmg_bool.c	(revision 53996)
+++ src/librt/primitives/nmg/nmg_bool.c	(working copy)
@@ -1294,7 +1294,7 @@
 /**
  * N M G _ B O O L T R E E _ E V A L U A T E
  *
- * Given a tree of leaf nodes tesselated earlier by
+ * Given a tree of leaf nodes tessellated earlier by
  * nmg_booltree_leaf_tess(), use recursion to do a depth-first
  * traversal of the tree, evaluating each pair of boolean operations
  * and reducing that result to a single nmgregion.
Index: src/librt/primitives/nmg/nmg_tri_mc.c
===================================================================
--- src/librt/primitives/nmg/nmg_tri_mc.c	(revision 53996)
+++ src/librt/primitives/nmg/nmg_tri_mc.c	(working copy)
@@ -43,7 +43,7 @@
 /** @} */
 
 /* rough game plan
- *   [ ] develop/proof metaball primitive tesselation using MC (end of Jan10)
+ *   [ ] develop/proof metaball primitive tessellation using MC (end of Jan10)
  *       [ ] asc-g/g-asc of metaballs for regression/comparison testing
  *           [X] asc-g
  *           [X] g-asc
Index: src/other/boost/boost/spirit/home/classic/phoenix/binders.hpp
===================================================================
--- src/other/boost/boost/spirit/home/classic/phoenix/binders.hpp	(revision 53996)
+++ src/other/boost/boost/spirit/home/classic/phoenix/binders.hpp	(working copy)
@@ -20,7 +20,7 @@
 //
 //  Binders
 //
-//      There are times when it is desireable to bind a simple functor,
+//      There are times when it is desirable to bind a simple functor,
 //      function, member function or member variable for deferred
 //      evaluation. This can be done through the binding facilities
 //      provided below. There are template classes:
Index: src/other/boost/boost/spirit/home/classic/phoenix/operators.hpp
===================================================================
--- src/other/boost/boost/spirit/home/classic/phoenix/operators.hpp	(revision 53996)
+++ src/other/boost/boost/spirit/home/classic/phoenix/operators.hpp	(working copy)
@@ -345,7 +345,7 @@
 //      type of binary operators such as +. The type with the higher
 //      rank wins and is used as the operator's return type. T1 generic
 //      user defined type has a very high rank and always wins when
-//      compared against a user defined type. If this is not desireable,
+//      compared against a user defined type. If this is not desirable,
 //      one can write a rank specialization for the type.
 //
 //      Take note that ranks 0..9999 are reserved for the framework.
Index: src/other/libpng/CHANGES
===================================================================
--- src/other/libpng/CHANGES	(revision 53996)
+++ src/other/libpng/CHANGES	(working copy)
@@ -3725,7 +3725,7 @@
     gray (on palette) itself.
   Fixes for C++ compilation using g++ When libpng source is compiled
     using g++. The compiler imposes C++ rules on the C source; thus it
-    is desireable to make the source work with either C or C++ rules
+    is desirable to make the source work with either C or C++ rules
     without throwing away useful error information.  This change adds
     png_voidcast to allow C semantic (void*) cases or the corresponding
     C++ static_cast operation, as appropriate.
Index: src/other/libpng/pngrtran.c
===================================================================
--- src/other/libpng/pngrtran.c	(revision 53996)
+++ src/other/libpng/pngrtran.c	(working copy)
@@ -1282,7 +1282,7 @@
 
       else if (png_ptr->screen_gamma != 0)
          /* The converse - assume the file matches the screen, note that this
-          * perhaps undesireable default can (from 1.5.4) be changed by calling
+          * perhaps undesirable default can (from 1.5.4) be changed by calling
           * png_set_alpha_mode (even if the alpha handling mode isn't required
           * or isn't changed from the default.)
           */
Index: src/other/openNURBS/opennurbs_mesh.cpp
===================================================================
--- src/other/openNURBS/opennurbs_mesh.cpp	(revision 53996)
+++ src/other/openNURBS/opennurbs_mesh.cpp	(working copy)
@@ -4607,7 +4607,7 @@
     ei.flag = 16;
 
     // It is CRITICAL that the length compare use >=.
-    // Otherwise tesselations of equailateral triangles
+    // Otherwise tessellations of equailateral triangles
     // will not work right in this fuction.
     fei = top.m_topf[ei.fi[0]].m_topei;
     if (    ( i != fei[0] && EI[fei[0]].length >= ei.length )
@@ -4620,7 +4620,7 @@
     }
 
     // It is CRITICAL that the length compare use >=.
-    // Otherwise tesselations of equailateral triangles
+    // Otherwise tessellations of equailateral triangles
     // will not work right in this fuction.
     fei = top.m_topf[ei.fi[1]].m_topei;
     if (    ( i != fei[0] && EI[fei[0]].length >= ei.length )
Index: src/other/openNURBS/opennurbs_mesh.h
===================================================================
--- src/other/openNURBS/opennurbs_mesh.h	(revision 53996)
+++ src/other/openNURBS/opennurbs_mesh.h	(working copy)
@@ -1770,7 +1770,7 @@
   // Implementation - surface parameters and packed texture 
   // information
   //
-  // If m_S.Count() == m_V.Count(), then the mesh is a tesselation
+  // If m_S.Count() == m_V.Count(), then the mesh is a tessellation
   // of a parameteric surface and m_S[j] is the surface parameter at
   // m_V[j].  Storing values in m_S[] is OPTIONAL.
   //
Index: src/other/step/data/ifc2x4/IFC2X4_RC3.exp
===================================================================
--- src/other/step/data/ifc2x4/IFC2X4_RC3.exp	(revision 53996)
+++ src/other/step/data/ifc2x4/IFC2X4_RC3.exp	(working copy)
@@ -11846,7 +11846,7 @@
            END_REPEAT;
         END;
   
-      'Tesselation' :
+      'Tessellation' :
         BEGIN 
           Count := SIZEOF(QUERY(temp <* Items | 'IFC2X4_RC3.IFCTESSELATEDITEM' IN TYPEOF(temp)));
         END;
Index: src/other/tcl/generic/tclIOUtil.c
===================================================================
--- src/other/tcl/generic/tclIOUtil.c	(revision 53996)
+++ src/other/tcl/generic/tclIOUtil.c	(working copy)
@@ -4450,7 +4450,7 @@
  *	functions not in this file), then one cannot necessarily guarantee
  *	that the path object pointer is from the correct filesystem.
  *
- *	Note: in the future it might be desireable to have separate versions
+ *	Note: in the future it might be desirable to have separate versions
  *	of this function with different signatures, for example
  *	Tcl_FSGetNativeWinPath, Tcl_FSGetNativeUnixPath etc. Right now, since
  *	native paths are all string based, we use just one function.

Index: src/conv/dxf/g-dxf.c
===================================================================
--- src/conv/dxf/g-dxf.c	(revision 53996)
+++ src/conv/dxf/g-dxf.c	(working copy)
@@ -88,7 +88,7 @@
 static char	*output_file = NULL;	/* output filename */
 static FILE	*fp;		/* Output file pointer */
 static struct db_i		*dbip;
-static struct rt_tess_tol	ttol;	/* tesselation tolerance in mm */
+static struct rt_tess_tol	ttol;	/* tessellation tolerance in mm */
 static struct bn_tol		tol;	/* calculation tolerance */
 static struct model		*the_model;
 
@@ -397,7 +397,7 @@
     tree_state.ts_ttol = &ttol;
     tree_state.ts_m = &the_model;
 
     /* Set up tesselation tolerance defaults */
     ttol.magic = RT_TESS_TOL_MAGIC;
     /* Defaults, updated by command line options. */
     ttol.abs = 0.0;
@@ -504,7 +504,7 @@
 	bu_log("Objects:");
 	for (i = 1; i < argc; i++)
 	    bu_log(" %s", argv[i]);
-	bu_log("\nTesselation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
+	bu_log("\nTessellation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
 		tree_state.ts_ttol->abs, tree_state.ts_ttol->rel, tree_state.ts_ttol->norm);
 	bu_log("Calculational tolerances:\n\tdist = %g mm perp = %g\n",
 		tree_state.ts_tol->dist, tree_state.ts_tol->perp);
@@ -397,7 +397,7 @@
     tree_state.ts_m = &the_model;
 
-    /* Set up tesselation tolerance defaults */
+    /* Set up tessellation tolerance defaults */
     ttol.magic = RT_TESS_TOL_MAGIC;
     /* Defaults, updated by command line options. */
Index: src/conv/g-egg.c
===================================================================
--- src/conv/g-egg.c	(revision 53996)
+++ src/conv/g-egg.c	(working copy)
@@ -183,7 +183,7 @@
     char *output_file = NULL;	/* output filename */
     struct db_i *dbip;
     struct model *the_model;
-    struct rt_tess_tol ttol;		/* tesselation tolerance in mm */
+    struct rt_tess_tol ttol;		/* tessellation tolerance in mm */
     struct db_tree_state tree_state;	/* includes tol & model */
 
     int i, use_mc = 0, use_bottess = 0;
@@ -196,7 +196,7 @@
     tree_state.ts_ttol = &ttol;
     tree_state.ts_m = &the_model;
 
     /* Set up tesselation tolerance defaults */
     ttol.magic = RT_TESS_TOL_MAGIC;
     /* Defaults, updated by command line options. */
     ttol.abs = 0.0;
@@ -306,7 +306,7 @@
 	bu_log("Objects:");
 	for (i=1; i<argc; i++)
 	    bu_log(" %s", argv[i]);
-	bu_log("\nTesselation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
+	bu_log("\nTessellation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
 	       tree_state.ts_ttol->abs, tree_state.ts_ttol->rel, tree_state.ts_ttol->norm);
 	bu_log("Calculational tolerances:\n\tdist = %g mm perp = %g\n",
 	       tree_state.ts_tol->dist, tree_state.ts_tol->perp);
@@ -196,7 +196,7 @@
     tree_state.ts_m = &the_model;
 
-    /* Set up tesselation tolerance defaults */
+    /* Set up tessellation tolerance defaults */
     ttol.magic = RT_TESS_TOL_MAGIC;
     /* Defaults, updated by command line options. */
Index: src/conv/g-xxx_facets.c
===================================================================
--- src/conv/g-xxx_facets.c	(revision 53996)
+++ src/conv/g-xxx_facets.c	(working copy)
@@ -57,7 +57,7 @@
 static int	NMG_debug;	/* saved arg of -X, for longjmp handling */
 static int	verbose;
 static struct db_i		*dbip;
-static struct rt_tess_tol	ttol;	/* tesselation tolerance in mm */
+static struct rt_tess_tol	ttol;	/* tessellation tolerance in mm */
 static struct bn_tol		tol;	/* calculation tolerance */
 static struct model		*the_model;
 
@@ -86,7 +86,7 @@
     tree_state.ts_ttol = &ttol;
     tree_state.ts_m = &the_model;
 
     /* Set up tesselation tolerance defaults */
     ttol.magic = RT_TESS_TOL_MAGIC;
     /* Defaults, updated by command line options. */
     ttol.abs = 0.0;
@@ -171,7 +171,7 @@
 	bu_log("Objects:");
 	for (i = 1; i < argc; i++)
 	    bu_log(" %s", argv[i]);
-	bu_log("\nTesselation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
+	bu_log("\nTessellation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
 		tree_state.ts_ttol->abs, tree_state.ts_ttol->rel, tree_state.ts_ttol->norm);
 	bu_log("Calculational tolerances:\n\tdist = %g mm perp = %g\n",
 		tree_state.ts_tol->dist, tree_state.ts_tol->perp);
@@ -202,7 +202,7 @@
 
     bu_log("%zd triangles written\n", tot_polygons);
 
-    bu_log("Tesselation parameters used:\n");
+    bu_log("Tessellation parameters used:\n");
     bu_log("  abs  [-a]    %g\n", ttol.abs);
     bu_log("  rel  [-r]    %g\n", ttol.rel);
     bu_log("  norm [-n]    %g\n", ttol.norm);
@@ -86,7 +86,7 @@
     tree_state.ts_m = &the_model;
 
-    /* Set up tesselation tolerance defaults */
+    /* Set up tessellation tolerance defaults */
     ttol.magic = RT_TESS_TOL_MAGIC;
     /* Defaults, updated by command line options. */
Index: src/conv/stl/g-stl.c
===================================================================
--- src/conv/stl/g-stl.c	(revision 53996)
+++ src/conv/stl/g-stl.c	(working copy)
@@ -66,7 +66,7 @@
 static struct db_i *dbip;
 static struct model *the_model;
 static struct bu_vls file_name = BU_VLS_INIT_ZERO;		/* file name built from region name */
-static struct rt_tess_tol ttol;		/* tesselation tolerance in mm */
+static struct rt_tess_tol ttol;		/* tessellation tolerance in mm */
 static struct bn_tol tol;		/* calculation tolerance */
 static struct db_tree_state tree_state;	/* includes tol & model */
 
@@ -319,7 +319,7 @@
     tree_state.ts_ttol = &ttol;
     tree_state.ts_m = &the_model;
 
     /* Set up tesselation tolerance defaults */
     ttol.magic = RT_TESS_TOL_MAGIC;
     /* Defaults, updated by command line options. */
     ttol.abs = 0.0;
@@ -446,7 +446,7 @@
 	bu_log("Objects:");
 	for (i=1; i<argc; i++)
 	    bu_log(" %s", argv[i]);
-	bu_log("\nTesselation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
+	bu_log("\nTessellation tolerances:\n\tabs = %g mm\n\trel = %g\n\tnorm = %g\n",
 	       tree_state.ts_ttol->abs, tree_state.ts_ttol->rel, tree_state.ts_ttol->norm);
 	bu_log("Calculational tolerances:\n\tdist = %g mm perp = %g\n",
 	       tree_state.ts_tol->dist, tree_state.ts_tol->perp);
@@ -319,7 +319,7 @@
     tree_state.ts_m = &the_model;
 
-    /* Set up tesselation tolerance defaults */
+    /* Set up tessellation tolerance defaults */
     ttol.magic = RT_TESS_TOL_MAGIC;
     /* Defaults, updated by command line options. */
Index: src/librt/primitives/tgc/tgc.c
===================================================================
--- src/librt/primitives/tgc/tgc.c	(revision 53996)
+++ src/librt/primitives/tgc/tgc.c	(working copy)
@@ -2049,7 +2049,7 @@
 /**
  * R T _ T G C _ T E S S
  *
  * Tesselation of the TGC.
  *
  * Returns -
  * -1 failure
@@ -2107,7 +2107,7 @@
     RT_TGC_CK_MAGIC(tip);
 
     if (ttol->abs > 0.0 && ttol->abs < tol->dist) {
-	bu_log("WARNING: tesselation tolerance is %fmm while calculational tolerance is %fmm\n",
+	bu_log("WARNING: tessellation tolerance is %fmm while calculational tolerance is %fmm\n",
 	       ttol->abs, tol->dist);
 	bu_log("Cannot tesselate a TGC to finer tolerance than the calculational tolerance\n");
 	abs_tol = tol->dist;
@@ -2741,7 +2741,7 @@
  *
  * Returns -
  * -1 failure
  * 0 OK. *r points to nmgregion that holds this tesselation
  */
 
 int
@@ -2049,7 +2049,7 @@
  * R T _ T G C _ T E S S
  *
- * Tesselation of the TGC.
+ * Tessellation of the TGC.
  *
  * Returns -
@@ -2741,7 +2741,7 @@
  * Returns -
  * -1 failure
- * 0 OK. *r points to nmgregion that holds this tesselation
+ * 0 OK. *r points to nmgregion that holds this tessellation
  */
 